pub struct Packet<'a> {
pub message: TracingWire<'a>,
pub tick: u64,
}Expand description
A tracing wire Packet type
This type is the “outer wrapper”, typically sent as the single message on the wire. Devices producing tracing messages will emit a stream of Packets, which will be individually processed by the remote collector
Fields
message: TracingWire<'a>tick: u64Trait Implementations
Sourceimpl<'de: 'a, 'a> Deserialize<'de> for Packet<'a>
impl<'de: 'a, 'a> Deserialize<'de> for Packet<'a>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more