pub enum TWOther {
MessageDiscarded,
DeviceInfo {
clock_id: u32,
ticks_per_sec: u32,
device_id: [u8; 16],
},
}Expand description
Tracing Wire “Other” messages
This type contains messages that are not directly sourced from tracing events, but are sometimes necessary during establishing or maintaining of the connection.
Variants
MessageDiscarded
One or more events have been discarded without being transmitted via a Packet.
This is used when the local buffer has become full, and it was no longer possible
to transmit the stream of events uninterrupted.
DeviceInfo
A collection of metadata items about the device that is producing trace events.